#
# Barpanel Stalonetray plugin
# 
# Copyright (C) 2008 Job and Esther Technologies Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#

name = "Stalonetray"
description = "System tray implementation using the stalonetray application"

import barpanel, gtk, gobject

class Plugin(barpanel.Plugin):
    def __init__(self, panel, settings):
        barpanel.Plugin.__init__(self, panel, settings)
        self.set_name("BarpanelStalonetray")
        self.astate = 0
        self.set_border_width(3)
        self.command = "stalonetray -p"
        self.widthr = 128
        if self.settings.has_key("command"):
            self.command = self.settings['command']
        if self.settings.has_key("width"):
            self.widthr = int(self.settings['width'])
        self.update()
        #gobject.timeout_add(5 * 1000, self.checkForSize)

    def update(self):
        if self.astate == 0 and len(self.command)>0:
            self.logINFO("No swallowed window available. Starting new child process..")
            self.astate = 1
            self.socket = gtk.Socket()
            self.socket.connect("plug-added", self.onPlugAdded)
            self.socket.connect("plug-removed", self.onPlugRemoved)
            self.add(self.socket)
            barpanel.launch_command(self.command)
            gobject.timeout_add(1000, self.waitForWindow)

    def checkForSize(self):
        #sr = self.fw.get_size()
        #self.logDEBUG("Child process size request %s" % (str(sr)))
        #self.socket.set_size_request(sr[0], sr[1])
        self.logDEBUG("Setting system tray size to (%d, 24) as configured." % (self.widthr))
        self.socket.set_size_request(self.widthr, 24)
        return(True)

    def waitForWindow(self):
        root = gtk.gdk.get_default_root_window()
        prop = root.property_get("_NET_CLIENT_LIST")
        for wid in prop[2]:
            fw = gtk.gdk.window_foreign_new(wid)
            name = fw.property_get("WM_NAME")[2]
            if name == "stalonetray":
                self.fw = fw
                self.logDEBUG("Found stalonetray with window id %02x. Swallowing window.." % (wid))
                self.socket.add_id(wid)
                self.checkForSize()
                self.astate = 2
        if self.astate == 1:
            return(True)
        return(False)

    def onPlugAdded(self, a):
        self.logDEBUG("Window successfully swallowed.")
        self.astate = 3
        self.socket.show()
        self.update()

    def onPlugRemoved(self, a):
        self.logDEBUG("Swallowed window lost.")
        self.astate = 0
        self.update()
